"""Parameter maps for registration."""

from __future__ import annotations

OLD_TO_NEW_MAP: dict[str, str] = {}

DEFAULT_REGISTRATION_PARAMETERS_MAP = {
    "rigid": {
        "AutomaticScalesEstimation": ["true"],
        "AutomaticTransformInitialization": ["true"],
        "BSplineInterpolationOrder": ["1"],
        "CompressResultImage": ["true"],
        "DefaultPixelValue": ["0"],
        "ErodeMask": ["false"],  # could also be true - need to experiment
        "FinalBSplineInterpolationOrder": ["1"],
        "FixedImageDimension": ["2"],
        "FixedImagePyramid": ["FixedRecursiveImagePyramid"],
        "FixedInternalImagePixelType": ["float"],
        "HowToCombineTransforms": ["Compose"],
        "ImageSampler": ["Random"],
        "Interpolator": ["LinearInterpolator"],
        "MaximumNumberOfIterations": ["200"],
        "MaximumNumberOfSamplingAttempts": ["25"],
        "MaximumStepLength": [
            "100.0",
            "75.0",
            "66.0",
            "50.0",
            "25.0",
            "15.0",
            "10.0",
            "10.0",
            "5.0",
            "1.0",
        ],
        "Metric": ["AdvancedMattesMutualInformation"],
        "MovingImageDimension": ["2"],
        "MovingImagePyramid": ["MovingRecursiveImagePyramid"],
        "MovingInternalImagePixelType": ["float"],
        "NewSamplesEveryIteration": ["true"],
        "NumberOfHistogramBins": ["16"],
        "NumberOfResolutions": ["10"],
        "NumberOfSpatialSamples": ["10000"],
        "Optimizer": ["AdaptiveStochasticGradientDescent"],
        "Registration": ["MultiResolutionRegistration"],
        "RequiredRatioOfValidSamples": ["0.05"],
        "ResampleInterpolator": ["FinalNearestNeighborInterpolator"],
        "Resampler": ["DefaultResampler"],
        "ResultImageFormat": ["mha"],
        "ResultImagePixelType": ["short"],
        "Transform": ["EulerTransform"],
        "UseDirectionCosines": ["true"],
        "WriteResultImage": ["false"],
        "WriteTransformParametersEachResolution": ["true"],
    },
    "rigid_expanded": {
        "AutomaticScalesEstimation": ["true"],
        "AutomaticTransformInitialization": ["true"],
        "BSplineInterpolationOrder": ["1"],
        "CompressResultImage": ["true"],
        "DefaultPixelValue": ["0"],
        "ErodeMask": ["false"],  # could also be true - need to experiment
        "FinalBSplineInterpolationOrder": ["1"],
        "FixedImageDimension": ["2"],
        "FixedImagePyramid": ["FixedRecursiveImagePyramid"],
        "FixedInternalImagePixelType": ["float"],
        "HowToCombineTransforms": ["Compose"],
        "ImageSampler": ["Random"],
        "Interpolator": ["LinearInterpolator"],
        "MaximumNumberOfIterations": ["500"],
        "MaximumNumberOfSamplingAttempts": ["25"],
        "MaximumStepLength": [
            "100.0",
            "75.0",
            "66.0",
            "50.0",
            "25.0",
            "15.0",
            "10.0",
            "10.0",
            "5.0",
            "1.0",
        ],
        "Metric": ["AdvancedMattesMutualInformation"],
        "MovingImageDimension": ["2"],
        "MovingImagePyramid": ["MovingRecursiveImagePyramid"],
        "MovingInternalImagePixelType": ["float"],
        "NewSamplesEveryIteration": ["true"],
        "NumberOfHistogramBins": ["16"],
        "NumberOfResolutions": ["10"],
        "NumberOfSpatialSamples": ["30000"],
        "Optimizer": ["AdaptiveStochasticGradientDescent"],
        "Registration": ["MultiResolutionRegistration"],
        "RequiredRatioOfValidSamples": ["0.05"],
        "ResampleInterpolator": ["FinalNearestNeighborInterpolator"],
        "Resampler": ["DefaultResampler"],
        "ResultImageFormat": ["mha"],
        "ResultImagePixelType": ["short"],
        "Transform": ["EulerTransform"],
        "UseDirectionCosines": ["true"],
        "WriteResultImage": ["false"],
        "WriteTransformParametersEachResolution": ["true"],
    },
    "rigid_extreme": {
        "AutomaticScalesEstimation": ["true"],
        "AutomaticTransformInitialization": ["true"],
        "BSplineInterpolationOrder": ["1"],
        "CompressResultImage": ["true"],
        "DefaultPixelValue": ["0"],
        "ErodeMask": ["false"],  # could also be true - need to experiment
        "FinalBSplineInterpolationOrder": ["1"],
        "FixedImageDimension": ["2"],
        "FixedImagePyramid": ["FixedRecursiveImagePyramid"],
        "FixedInternalImagePixelType": ["float"],
        "HowToCombineTransforms": ["Compose"],
        "ImageSampler": ["Random"],
        "Interpolator": ["LinearInterpolator"],
        "MaximumNumberOfIterations": ["500"],
        "MaximumNumberOfSamplingAttempts": ["25"],
        "MaximumStepLength": [
            "100.0",
            "75.0",
            "66.0",
            "50.0",
            "25.0",
            "15.0",
            "10.0",
            "10.0",
            "5.0",
            "1.0",
        ],
        "Metric": ["AdvancedMattesMutualInformation"],
        "MovingImageDimension": ["2"],
        "MovingImagePyramid": ["MovingRecursiveImagePyramid"],
        "MovingInternalImagePixelType": ["float"],
        "NewSamplesEveryIteration": ["true"],
        "NumberOfHistogramBins": ["16"],
        "NumberOfResolutions": ["10"],
        "NumberOfSpatialSamples": ["75000"],
        "Optimizer": ["AdaptiveStochasticGradientDescent"],
        "Registration": ["MultiResolutionRegistration"],
        "RequiredRatioOfValidSamples": ["0.05"],
        "ResampleInterpolator": ["FinalNearestNeighborInterpolator"],
        "Resampler": ["DefaultResampler"],
        "ResultImageFormat": ["mha"],
        "ResultImagePixelType": ["short"],
        "Transform": ["EulerTransform"],
        "UseDirectionCosines": ["true"],
        "WriteResultImage": ["false"],
        "WriteTransformParametersEachResolution": ["true"],
    },
    "affine": {
        "AutomaticScalesEstimation": ["true"],
        "AutomaticTransformInitialization": ["true"],
        "BSplineInterpolationOrder": ["1"],
        "CompressResultImage": ["true"],
        "DefaultPixelValue": ["0"],
        "ErodeMask": ["false"],  # could also be true - need to experiment
        "FinalBSplineInterpolationOrder": ["1"],
        "FixedImageDimension": ["2"],
        "FixedImagePyramid": ["FixedRecursiveImagePyramid"],
        "FixedInternalImagePixelType": ["float"],
        "HowToCombineTransforms": ["Compose"],
        "ImageSampler": ["Random"],
        "Interpolator": ["LinearInterpolator"],
        "MaximumNumberOfIterations": ["200"],
        "MaximumNumberOfSamplingAttempts": ["25"],
        "MaximumStepLength": [
            "100.0",
            "75.0",
            "66.0",
            "50.0",
            "25.0",
            "15.0",
            "10.0",
            "10.0",
            "5.0",
            "1.0",
        ],
        "Metric": ["AdvancedMattesMutualInformation"],
        "MovingImageDimension": ["2"],
        "MovingImagePyramid": ["MovingRecursiveImagePyramid"],
        "MovingInternalImagePixelType": ["float"],
        "NewSamplesEveryIteration": ["true"],
        "NumberOfHistogramBins": ["32"],
        "NumberOfResolutions": ["10"],
        "NumberOfSpatialSamples": ["10000"],
        "Optimizer": ["AdaptiveStochasticGradientDescent"],
        "Registration": ["MultiResolutionRegistration"],
        "RequiredRatioOfValidSamples": ["0.05"],
        "ResampleInterpolator": ["FinalNearestNeighborInterpolator"],
        "Resampler": ["DefaultResampler"],
        "ResultImageFormat": ["mha"],
        "ResultImagePixelType": ["short"],
        "Transform": ["AffineTransform"],
        "UseDirectionCosines": ["true"],
        "WriteResultImage": ["false"],
        "WriteTransformParametersEachResolution": ["true"],
    },
    "affine_expanded": {
        "AutomaticScalesEstimation": ["true"],
        "AutomaticTransformInitialization": ["true"],
        "BSplineInterpolationOrder": ["1"],
        "CompressResultImage": ["true"],
        "DefaultPixelValue": ["0"],
        "ErodeMask": ["false"],  # could also be true - need to experiment
        "FinalBSplineInterpolationOrder": ["1"],
        "FixedImageDimension": ["2"],
        "FixedImagePyramid": ["FixedRecursiveImagePyramid"],
        "FixedInternalImagePixelType": ["float"],
        "HowToCombineTransforms": ["Compose"],
        "ImageSampler": ["Random"],
        "Interpolator": ["LinearInterpolator"],
        "MaximumNumberOfIterations": ["500"],
        "MaximumNumberOfSamplingAttempts": ["25"],
        "MaximumStepLength": [
            "100.0",
            "75.0",
            "66.0",
            "50.0",
            "25.0",
            "15.0",
            "10.0",
            "10.0",
            "5.0",
            "1.0",
        ],
        "Metric": ["AdvancedMattesMutualInformation"],
        "MovingImageDimension": ["2"],
        "MovingImagePyramid": ["MovingRecursiveImagePyramid"],
        "MovingInternalImagePixelType": ["float"],
        "NewSamplesEveryIteration": ["true"],
        "NumberOfHistogramBins": ["32"],
        "NumberOfResolutions": ["10"],
        "NumberOfSpatialSamples": ["30000"],
        "Optimizer": ["AdaptiveStochasticGradientDescent"],
        "Registration": ["MultiResolutionRegistration"],
        "RequiredRatioOfValidSamples": ["0.05"],
        "ResampleInterpolator": ["FinalNearestNeighborInterpolator"],
        "Resampler": ["DefaultResampler"],
        "ResultImageFormat": ["mha"],
        "ResultImagePixelType": ["short"],
        "Transform": ["AffineTransform"],
        "UseDirectionCosines": ["true"],
        "WriteResultImage": ["false"],
        "WriteTransformParametersEachResolution": ["true"],
    },
    "affine_extreme": {
        "AutomaticScalesEstimation": ["true"],
        "AutomaticTransformInitialization": ["true"],
        "BSplineInterpolationOrder": ["1"],
        "CompressResultImage": ["true"],
        "DefaultPixelValue": ["0"],
        "ErodeMask": ["false"],  # could also be true - need to experiment
        "FinalBSplineInterpolationOrder": ["1"],
        "FixedImageDimension": ["2"],
        "FixedImagePyramid": ["FixedRecursiveImagePyramid"],
        "FixedInternalImagePixelType": ["float"],
        "HowToCombineTransforms": ["Compose"],
        "ImageSampler": ["Random"],
        "Interpolator": ["LinearInterpolator"],
        "MaximumNumberOfIterations": ["500"],
        "MaximumNumberOfSamplingAttempts": ["25"],
        "MaximumStepLength": [
            "100.0",
            "75.0",
            "66.0",
            "50.0",
            "25.0",
            "15.0",
            "10.0",
            "10.0",
            "5.0",
            "1.0",
        ],
        "Metric": ["AdvancedMattesMutualInformation"],
        "MovingImageDimension": ["2"],
        "MovingImagePyramid": ["MovingRecursiveImagePyramid"],
        "MovingInternalImagePixelType": ["float"],
        "NewSamplesEveryIteration": ["true"],
        "NumberOfHistogramBins": ["32"],
        "NumberOfResolutions": ["10"],
        "NumberOfSpatialSamples": ["75000"],
        "Optimizer": ["AdaptiveStochasticGradientDescent"],
        "Registration": ["MultiResolutionRegistration"],
        "RequiredRatioOfValidSamples": ["0.05"],
        "ResampleInterpolator": ["FinalNearestNeighborInterpolator"],
        "Resampler": ["DefaultResampler"],
        "ResultImageFormat": ["mha"],
        "ResultImagePixelType": ["short"],
        "Transform": ["AffineTransform"],
        "UseDirectionCosines": ["true"],
        "WriteResultImage": ["false"],
        "WriteTransformParametersEachResolution": ["true"],
    },
    "similarity": {
        "AutomaticScalesEstimation": ["true"],
        "AutomaticTransformInitialization": ["true"],
        "BSplineInterpolationOrder": ["1"],
        "CompressResultImage": ["true"],
        "DefaultPixelValue": ["0"],
        "ErodeMask": ["false"],  # could also be true - need to experiment
        "FinalBSplineInterpolationOrder": ["1"],
        "FixedImageDimension": ["2"],
        "FixedImagePyramid": ["FixedRecursiveImagePyramid"],
        "FixedInternalImagePixelType": ["float"],
        "HowToCombineTransforms": ["Compose"],
        "ImageSampler": ["Random"],
        "Interpolator": ["LinearInterpolator"],
        "MaximumNumberOfIterations": ["200"],
        "MaximumNumberOfSamplingAttempts": ["25"],
        "MaximumStepLength": [
            "100.0",
            "75.0",
            "66.0",
            "50.0",
            "25.0",
            "15.0",
            "10.0",
            "10.0",
            "5.0",
            "1.0",
        ],
        "Metric": ["AdvancedMattesMutualInformation"],
        "MovingImageDimension": ["2"],
        "MovingImagePyramid": ["MovingRecursiveImagePyramid"],
        "MovingInternalImagePixelType": ["float"],
        "NewSamplesEveryIteration": ["true"],
        "NumberOfHistogramBins": ["32"],
        "NumberOfResolutions": ["10"],
        "NumberOfSpatialSamples": ["10000"],
        "Optimizer": ["AdaptiveStochasticGradientDescent"],
        "Registration": ["MultiResolutionRegistration"],
        "RequiredRatioOfValidSamples": ["0.05"],
        "ResampleInterpolator": ["FinalNearestNeighborInterpolator"],
        "Resampler": ["DefaultResampler"],
        "ResultImageFormat": ["mha"],
        "ResultImagePixelType": ["short"],
        "Transform": ["SimilarityTransform"],
        "UseDirectionCosines": ["true"],
        "WriteResultImage": ["false"],
        "WriteTransformParametersEachResolution": ["true"],
    },
    "similarity_expanded": {
        "AutomaticScalesEstimation": ["true"],
        "AutomaticTransformInitialization": ["true"],
        "BSplineInterpolationOrder": ["1"],
        "CompressResultImage": ["true"],
        "DefaultPixelValue": ["0"],
        "ErodeMask": ["false"],  # could also be true - need to experiment
        "FinalBSplineInterpolationOrder": ["1"],
        "FixedImageDimension": ["2"],
        "FixedImagePyramid": ["FixedRecursiveImagePyramid"],
        "FixedInternalImagePixelType": ["float"],
        "HowToCombineTransforms": ["Compose"],
        "ImageSampler": ["Random"],
        "Interpolator": ["LinearInterpolator"],
        "MaximumNumberOfIterations": ["200"],
        "MaximumNumberOfSamplingAttempts": ["25"],
        "MaximumStepLength": [
            "100.0",
            "75.0",
            "66.0",
            "50.0",
            "25.0",
            "15.0",
            "10.0",
            "10.0",
            "5.0",
            "1.0",
        ],
        "Metric": ["AdvancedMattesMutualInformation"],
        "MovingImageDimension": ["2"],
        "MovingImagePyramid": ["MovingRecursiveImagePyramid"],
        "MovingInternalImagePixelType": ["float"],
        "NewSamplesEveryIteration": ["true"],
        "NumberOfHistogramBins": ["32"],
        "NumberOfResolutions": ["10"],
        "NumberOfSpatialSamples": ["30000"],
        "Optimizer": ["AdaptiveStochasticGradientDescent"],
        "Registration": ["MultiResolutionRegistration"],
        "RequiredRatioOfValidSamples": ["0.05"],
        "ResampleInterpolator": ["FinalNearestNeighborInterpolator"],
        "Resampler": ["DefaultResampler"],
        "ResultImageFormat": ["mha"],
        "ResultImagePixelType": ["short"],
        "Transform": ["SimilarityTransform"],
        "UseDirectionCosines": ["true"],
        "WriteResultImage": ["false"],
        "WriteTransformParametersEachResolution": ["true"],
    },
    "similarity_extreme": {
        "AutomaticScalesEstimation": ["true"],
        "AutomaticTransformInitialization": ["true"],
        "BSplineInterpolationOrder": ["1"],
        "CompressResultImage": ["true"],
        "DefaultPixelValue": ["0"],
        "ErodeMask": ["false"],  # could also be true - need to experiment
        "FinalBSplineInterpolationOrder": ["1"],
        "FixedImageDimension": ["2"],
        "FixedImagePyramid": ["FixedRecursiveImagePyramid"],
        "FixedInternalImagePixelType": ["float"],
        "HowToCombineTransforms": ["Compose"],
        "ImageSampler": ["Random"],
        "Interpolator": ["LinearInterpolator"],
        "MaximumNumberOfIterations": ["200"],
        "MaximumNumberOfSamplingAttempts": ["25"],
        "MaximumStepLength": [
            "100.0",
            "75.0",
            "66.0",
            "50.0",
            "25.0",
            "15.0",
            "10.0",
            "10.0",
            "5.0",
            "1.0",
        ],
        "Metric": ["AdvancedMattesMutualInformation"],
        "MovingImageDimension": ["2"],
        "MovingImagePyramid": ["MovingRecursiveImagePyramid"],
        "MovingInternalImagePixelType": ["float"],
        "NewSamplesEveryIteration": ["true"],
        "NumberOfHistogramBins": ["32"],
        "NumberOfResolutions": ["10"],
        "NumberOfSpatialSamples": ["75000"],
        "Optimizer": ["AdaptiveStochasticGradientDescent"],
        "Registration": ["MultiResolutionRegistration"],
        "RequiredRatioOfValidSamples": ["0.05"],
        "ResampleInterpolator": ["FinalNearestNeighborInterpolator"],
        "Resampler": ["DefaultResampler"],
        "ResultImageFormat": ["mha"],
        "ResultImagePixelType": ["short"],
        "Transform": ["SimilarityTransform"],
        "UseDirectionCosines": ["true"],
        "WriteResultImage": ["false"],
        "WriteTransformParametersEachResolution": ["true"],
    },
    "nl": {
        "AutomaticScalesEstimation": ["true"],
        "AutomaticTransformInitialization": ["false"],
        "BSplineInterpolationOrder": ["1"],
        "CompressResultImage": ["true"],
        "DefaultPixelValue": ["0"],
        "ErodeMask": ["false"],  # could also be true - need to experiment
        "FinalBSplineInterpolationOrder": ["1"],
        "FinalGridSpacingInPhysicalUnits": ["100"],
        "FixedImageDimension": ["2"],
        "FixedImagePyramid": ["FixedRecursiveImagePyramid"],
        "FixedInternalImagePixelType": ["float"],
        "GridSpacingSchedule": [
            "512",
            "512",
            "392",
            "392",
            "256",
            "256",
            "128",
            "128",
            "64",
            "64",
            "32",
            "32",
            "16",
            "16",
            "4",
            "4",
            "2",
            "2",
            "1",
            "1",
        ],
        "HowToCombineTransforms": ["Compose"],
        "ImageSampler": ["Random"],
        "Interpolator": ["LinearInterpolator"],
        "MaximumNumberOfIterations": ["200"],
        "MaximumNumberOfSamplingAttempts": ["25"],
        "MaximumStepLength": [
            "100",
            "90",
            "70",
            "50",
            "40",
            "30",
            "20",
            "10",
            "1",
            "1",
        ],
        "Metric": ["AdvancedMattesMutualInformation"],
        "MovingImageDimension": ["2"],
        "MovingImagePyramid": ["MovingRecursiveImagePyramid"],
        "MovingInternalImagePixelType": ["float"],
        "NewSamplesEveryIteration": ["true"],
        "NumberOfHistogramBins": ["32"],
        "NumberOfResolutions": ["10"],
        "NumberOfSpatialSamples": ["50000"],
        "Optimizer": ["AdaptiveStochasticGradientDescent"],
        "Registration": ["MultiResolutionRegistration"],
        "RequiredRatioOfValidSamples": ["0.05"],
        "ResampleInterpolator": ["FinalNearestNeighborInterpolator"],
        "Resampler": ["DefaultResampler"],
        "ResultImageFormat": ["mha"],
        "ResultImagePixelType": ["short"],
        "Transform": ["BSplineTransform"],
        "UseDirectionCosines": ["true"],
        "WriteResultImage": ["false"],
        "WriteTransformParametersEachResolution": ["true"],
    },
    "nl_reduced": {
        "AutomaticScalesEstimation": ["true"],
        "AutomaticTransformInitialization": ["false"],
        "BSplineInterpolationOrder": ["1"],
        "CompressResultImage": ["true"],
        "DefaultPixelValue": ["0"],
        "ErodeMask": ["false"],  # could also be true - need to experiment
        "FinalBSplineInterpolationOrder": ["1"],
        "FinalGridSpacingInPhysicalUnits": ["100"],
        "FixedImageDimension": ["2"],
        "FixedImagePyramid": ["FixedRecursiveImagePyramid"],
        "FixedInternalImagePixelType": ["float"],
        "GridSpacingSchedule": [
            "392",
            "392",
            "256",
            "256",
            "128",
            "128",
            "64",
            "64",
            "32",
            "32",
        ],
        "HowToCombineTransforms": ["Compose"],
        "ImageSampler": ["Random"],
        "Interpolator": ["LinearInterpolator"],
        "MaximumNumberOfIterations": ["150"],
        "MaximumNumberOfSamplingAttempts": ["25"],
        "MaximumStepLength": [
            "50",
            "40",
            "30",
            "20",
        ],
        "Metric": ["AdvancedMattesMutualInformation"],
        "MovingImageDimension": ["2"],
        "MovingImagePyramid": ["MovingRecursiveImagePyramid"],
        "MovingInternalImagePixelType": ["float"],
        "NewSamplesEveryIteration": ["true"],
        "NumberOfHistogramBins": ["32"],
        "NumberOfResolutions": ["5"],
        "NumberOfSpatialSamples": ["50000"],
        "Optimizer": ["AdaptiveStochasticGradientDescent"],
        "Registration": ["MultiResolutionRegistration"],
        "RequiredRatioOfValidSamples": ["0.05"],
        "ResampleInterpolator": ["FinalNearestNeighborInterpolator"],
        "Resampler": ["DefaultResampler"],
        "ResultImageFormat": ["mha"],
        "ResultImagePixelType": ["short"],
        "Transform": ["BSplineTransform"],
        "UseDirectionCosines": ["true"],
        "WriteResultImage": ["false"],
        "WriteTransformParametersEachResolution": ["true"],
    },
    "nl_mid": {
        "AutomaticScalesEstimation": ["true"],
        "AutomaticTransformInitialization": ["false"],
        "BSplineInterpolationOrder": ["1"],
        "CompressResultImage": ["true"],
        "DefaultPixelValue": ["0"],
        "ErodeMask": ["false"],  # could also be true - need to experiment
        "FinalBSplineInterpolationOrder": ["1"],
        "FinalGridSpacingInPhysicalUnits": ["150"],
        "FixedImageDimension": ["2"],
        "FixedImagePyramid": ["FixedRecursiveImagePyramid"],
        "FixedInternalImagePixelType": ["float"],
        "GridSpacingSchedule": [
            "512",
            "512",
            "128",
            "128",
            "64",
            "64",
            "32",
            "32",
            "2",
            "2",
        ],
        "HowToCombineTransforms": ["Compose"],
        "ImageSampler": ["Random"],
        "Interpolator": ["LinearInterpolator"],
        "MaximumNumberOfIterations": ["200"],
        "MaximumNumberOfSamplingAttempts": ["25"],
        "MaximumStepLength": [
            "100",
            "70",
            "50",
            "30",
            "10",
        ],
        "Metric": ["AdvancedMattesMutualInformation"],
        "MovingImageDimension": ["2"],
        "MovingImagePyramid": ["MovingRecursiveImagePyramid"],
        "MovingInternalImagePixelType": ["float"],
        "NewSamplesEveryIteration": ["true"],
        "NumberOfHistogramBins": ["32"],
        "NumberOfResolutions": ["5"],
        "NumberOfSpatialSamples": ["50000"],
        "Optimizer": ["AdaptiveStochasticGradientDescent"],
        "Registration": ["MultiResolutionRegistration"],
        "RequiredRatioOfValidSamples": ["0.05"],
        "ResampleInterpolator": ["FinalNearestNeighborInterpolator"],
        "Resampler": ["DefaultResampler"],
        "ResultImageFormat": ["mha"],
        "ResultImagePixelType": ["short"],
        "Transform": ["BSplineTransform"],
        "UseDirectionCosines": ["true"],
        "WriteResultImage": ["false"],
        "WriteTransformParametersEachResolution": ["true"],
    },
    "nl_expanded": {
        "AutomaticScalesEstimation": ["true"],
        "AutomaticTransformInitialization": ["false"],
        "BSplineInterpolationOrder": ["1"],
        "CompressResultImage": ["true"],
        "DefaultPixelValue": ["0"],
        "ErodeMask": ["false"],  # could also be true - need to experiment
        "FinalBSplineInterpolationOrder": ["1"],
        "FinalGridSpacingInPhysicalUnits": ["50"],
        "FixedImageDimension": ["2"],
        "FixedImagePyramid": ["FixedRecursiveImagePyramid"],
        "FixedInternalImagePixelType": ["float"],
        "GridSpacingSchedule": [
            "512",
            "512",
            "392",
            "392",
            "256",
            "256",
            "128",
            "128",
            "64",
            "64",
            "32",
            "32",
            "16",
            "16",
            "4",
            "4",
            "2",
            "2",
            "1",
            "1",
        ],
        "HowToCombineTransforms": ["Compose"],
        "ImageSampler": ["Random"],
        "Interpolator": ["LinearInterpolator"],
        "MaximumNumberOfIterations": ["1000"],
        "MaximumNumberOfSamplingAttempts": ["25"],
        "MaximumStepLength": [
            "100",
            "90",
            "70",
            "50",
            "40",
            "30",
            "20",
            "10",
            "1",
            "1",
        ],
        "Metric": ["AdvancedMattesMutualInformation"],
        "MovingImageDimension": ["2"],
        "MovingImagePyramid": ["MovingRecursiveImagePyramid"],
        "MovingInternalImagePixelType": ["float"],
        "NewSamplesEveryIteration": ["true"],
        "NumberOfHistogramBins": ["32"],
        "NumberOfResolutions": ["10"],
        "NumberOfSpatialSamples": ["30000"],
        "Optimizer": ["AdaptiveStochasticGradientDescent"],
        "Registration": ["MultiResolutionRegistration"],
        "RequiredRatioOfValidSamples": ["0.05"],
        "ResampleInterpolator": ["FinalNearestNeighborInterpolator"],
        "Resampler": ["DefaultResampler"],
        "ResultImageFormat": ["mha"],
        "ResultImagePixelType": ["short"],
        "Transform": ["BSplineTransform"],
        "UseDirectionCosines": ["true"],
        "WriteResultImage": ["false"],
        "WriteTransformParametersEachResolution": ["true"],
    },
    "nl_extreme": {
        "AutomaticScalesEstimation": ["true"],
        "AutomaticTransformInitialization": ["false"],
        "BSplineInterpolationOrder": ["1"],
        "CompressResultImage": ["true"],
        "DefaultPixelValue": ["0"],
        "ErodeMask": ["false"],  # could also be true - need to experiment
        "FinalBSplineInterpolationOrder": ["1"],
        "FinalGridSpacingInPhysicalUnits": ["50"],
        "FixedImageDimension": ["2"],
        "FixedImagePyramid": ["FixedRecursiveImagePyramid"],
        "FixedInternalImagePixelType": ["float"],
        "GridSpacingSchedule": [
            "512",
            "512",
            "392",
            "392",
            "256",
            "256",
            "128",
            "128",
            "64",
            "64",
            "32",
            "32",
            "16",
            "16",
            "4",
            "4",
            "2",
            "2",
            "1",
            "1",
        ],
        "HowToCombineTransforms": ["Compose"],
        "ImageSampler": ["Random"],
        "Interpolator": ["LinearInterpolator"],
        "MaximumNumberOfIterations": ["1000"],
        "MaximumNumberOfSamplingAttempts": ["25"],
        "MaximumStepLength": [
            "100",
            "90",
            "70",
            "50",
            "40",
            "30",
            "20",
            "10",
            "1",
            "1",
        ],
        "Metric": ["AdvancedMattesMutualInformation"],
        "MovingImageDimension": ["2"],
        "MovingImagePyramid": ["MovingRecursiveImagePyramid"],
        "MovingInternalImagePixelType": ["float"],
        "NewSamplesEveryIteration": ["true"],
        "NumberOfHistogramBins": ["32"],
        "NumberOfResolutions": ["10"],
        "NumberOfSpatialSamples": ["75000"],
        "Optimizer": ["AdaptiveStochasticGradientDescent"],
        "Registration": ["MultiResolutionRegistration"],
        "RequiredRatioOfValidSamples": ["0.05"],
        "ResampleInterpolator": ["FinalNearestNeighborInterpolator"],
        "Resampler": ["DefaultResampler"],
        "ResultImageFormat": ["mha"],
        "ResultImagePixelType": ["short"],
        "Transform": ["BSplineTransform"],
        "UseDirectionCosines": ["true"],
        "WriteResultImage": ["false"],
        "WriteTransformParametersEachResolution": ["true"],
    },
    "nl2": {
        "AutomaticScalesEstimation": ["true"],
        "AutomaticTransformInitialization": ["false"],
        "BSplineInterpolationOrder": ["1"],
        "CompressResultImage": ["true"],
        "DefaultPixelValue": ["0"],
        "ErodeMask": ["false"],  # could also be true - need to experiment
        "FinalBSplineInterpolationOrder": ["1"],
        "FinalGridSpacingInPhysicalUnits": ["75"],
        "FixedImageDimension": ["2"],
        "FixedImagePyramid": ["FixedRecursiveImagePyramid"],
        "FixedInternalImagePixelType": ["float"],
        "GridSpacingSchedule": [
            "512",
            "512",
            "392",
            "392",
            "256",
            "256",
            "128",
            "128",
            "64",
            "64",
            "32",
            "32",
            "16",
            "16",
            "4",
            "4",
            "2",
            "2",
            "1",
            "1",
        ],
        "HowToCombineTransforms": ["Compose"],
        "ImageSampler": ["Random"],
        "Interpolator": ["LinearInterpolator"],
        "MaximumNumberOfIterations": ["200"],
        "MaximumNumberOfSamplingAttempts": ["25"],
        "MaximumStepLength": [
            "25",
            "20",
            "15",
            "10",
            "10",
            "8",
            "5",
            "5",
            "5",
            "2",
        ],
        # "MaximumStepLength": [
        #     '50',
        #     '45',
        #     '40',
        #     '35',
        #     '30',
        #     '25',
        #     '5',
        #     '5',
        #     '5',
        #     '2',
        # ],
        "Metric": ["AdvancedMattesMutualInformation"],
        "MovingImageDimension": ["2"],
        "MovingImagePyramid": ["MovingRecursiveImagePyramid"],
        "MovingInternalImagePixelType": ["float"],
        "NewSamplesEveryIteration": ["true"],
        "NumberOfHistogramBins": ["32"],
        "NumberOfResolutions": ["10"],
        "NumberOfSpatialSamples": ["15000"],
        "Optimizer": ["AdaptiveStochasticGradientDescent"],
        "Registration": ["MultiResolutionRegistration"],
        "RequiredRatioOfValidSamples": ["0.05"],
        "ResampleInterpolator": ["FinalNearestNeighborInterpolator"],
        "Resampler": ["DefaultResampler"],
        "ResultImageFormat": ["mha"],
        "ResultImagePixelType": ["short"],
        "Transform": ["BSplineTransform"],
        "UseDirectionCosines": ["true"],
        "WriteResultImage": ["false"],
        "WriteTransformParametersEachResolution": ["true"],
    },
    "nl3": {
        "AutomaticScalesEstimation": ["true"],
        "AutomaticTransformInitialization": ["false"],
        "BSplineInterpolationOrder": ["1"],
        "CompressResultImage": ["true"],
        "DefaultPixelValue": ["0"],
        "ErodeMask": ["false"],  # could also be true - need to experiment
        "FinalBSplineInterpolationOrder": ["1"],
        "FinalGridSpacingInPhysicalUnits": ["200"],
        "FixedImageDimension": ["2"],
        "FixedImagePyramid": ["FixedRecursiveImagePyramid"],
        "FixedImagePyramidSchedule": [str(2**2), str(2**2)],
        "FixedInternalImagePixelType": ["float"],
        "GridSpacingSchedule": [
            "8",
            "8",
        ],
        "HowToCombineTransforms": ["Compose"],
        "ImageSampler": ["Random"],
        "Interpolator": ["LinearInterpolator"],
        "MaximumNumberOfIterations": ["1000"],
        "MaximumNumberOfSamplingAttempts": ["25"],
        "MaximumStepLength": [
            "10",
        ],
        "Metric": ["AdvancedMattesMutualInformation"],
        "MovingImageDimension": ["2"],
        "MovingImagePyramid": ["MovingRecursiveImagePyramid"],
        "MovingImagePyramidSchedule": [str(2**2), str(2**2)],
        "MovingInternalImagePixelType": ["float"],
        "NewSamplesEveryIteration": ["true"],
        "NumberOfHistogramBins": ["32"],
        "NumberOfResolutions": ["1"],
        "NumberOfSpatialSamples": ["125000"],
        "Optimizer": ["AdaptiveStochasticGradientDescent"],
        "Registration": ["MultiResolutionRegistration"],
        "RequiredRatioOfValidSamples": ["0.05"],
        "ResampleInterpolator": ["FinalNearestNeighborInterpolator"],
        "Resampler": ["DefaultResampler"],
        "ResultImageFormat": ["mha"],
        "ResultImagePixelType": ["short"],
        "Transform": ["BSplineTransform"],
        "UseDirectionCosines": ["true"],
        "WriteResultImage": ["false"],
        "WriteTransformParametersEachResolution": ["true"],
    },
    "fi_correction": {
        "AutomaticScalesEstimation": ["true"],
        "AutomaticTransformInitialization": ["false"],
        "BSplineInterpolationOrder": ["1"],
        "CompressResultImage": ["true"],
        "DefaultPixelValue": ["0"],
        "ErodeMask": ["false"],  # could also be true - need to experiment
        "FinalBSplineInterpolationOrder": ["1"],
        "FixedImageDimension": ["2"],
        "FixedImagePyramid": ["FixedRecursiveImagePyramid"],
        "FixedInternalImagePixelType": ["float"],
        "HowToCombineTransforms": ["Compose"],
        "ImagePyramidSchedule": ["8", "8", "4", "4", "2", "2", "1", "1"],
        "ImageSampler": ["Random"],
        "Interpolator": ["LinearInterpolator"],
        "MaximumNumberOfIterations": ["75"],
        "MaximumNumberOfSamplingAttempts": ["25"],
        "MaximumStepLength": ["100", "50", "20", "10"],
        "Metric": ["AdvancedMattesMutualInformation"],
        "MovingImageDimension": ["2"],
        "MovingImagePyramid": ["MovingRecursiveImagePyramid"],
        "MovingInternalImagePixelType": ["float"],
        "NewSamplesEveryIteration": ["true"],
        "NumberOfHistogramBins": ["16"],
        "NumberOfResolutions": ["4"],
        "NumberOfSpatialSamples": ["10000"],
        "Optimizer": ["AdaptiveStochasticGradientDescent"],
        "Registration": ["MultiResolutionRegistration"],
        "RequiredRatioOfValidSamples": ["0.05"],
        "ResampleInterpolator": ["FinalNearestNeighborInterpolator"],
        "Resampler": ["DefaultResampler"],
        "ResultImageFormat": ["mha"],
        "ResultImagePixelType": ["short"],
        "Transform": ["EulerTransform"],
        "UseDirectionCosines": ["true"],
        "WriteResultImage": ["true"],
        "WriteTransformParametersEachResolution": ["false"],
    },
}

# advanced mean squares
DEFAULT_REGISTRATION_PARAMETERS_MAP["rigid_ams"] = DEFAULT_REGISTRATION_PARAMETERS_MAP["rigid"].copy()
DEFAULT_REGISTRATION_PARAMETERS_MAP["rigid_ams"]["Metric"] = ["AdvancedMeanSquares"]
DEFAULT_REGISTRATION_PARAMETERS_MAP["affine_ams"] = DEFAULT_REGISTRATION_PARAMETERS_MAP["affine"].copy()
DEFAULT_REGISTRATION_PARAMETERS_MAP["affine_ams"]["Metric"] = ["AdvancedMeanSquares"]
DEFAULT_REGISTRATION_PARAMETERS_MAP["similarity_ams"] = DEFAULT_REGISTRATION_PARAMETERS_MAP["similarity"].copy()
DEFAULT_REGISTRATION_PARAMETERS_MAP["similarity_ams"]["Metric"] = ["AdvancedMeanSquares"]
DEFAULT_REGISTRATION_PARAMETERS_MAP["nl_ams"] = DEFAULT_REGISTRATION_PARAMETERS_MAP["nl"].copy()
DEFAULT_REGISTRATION_PARAMETERS_MAP["nl_ams"]["Metric"] = ["AdvancedMeanSquares"]

# normalized correlation
DEFAULT_REGISTRATION_PARAMETERS_MAP["rigid_anc"] = DEFAULT_REGISTRATION_PARAMETERS_MAP["rigid"].copy()
DEFAULT_REGISTRATION_PARAMETERS_MAP["rigid_anc"]["Metric"] = ["AdvancedNormalizedCorrelation"]
DEFAULT_REGISTRATION_PARAMETERS_MAP["affine_anc"] = DEFAULT_REGISTRATION_PARAMETERS_MAP["affine"].copy()
DEFAULT_REGISTRATION_PARAMETERS_MAP["affine_anc"]["Metric"] = ["AdvancedNormalizedCorrelation"]
DEFAULT_REGISTRATION_PARAMETERS_MAP["similarity_anc"] = DEFAULT_REGISTRATION_PARAMETERS_MAP["similarity"].copy()
DEFAULT_REGISTRATION_PARAMETERS_MAP["similarity_anc"]["Metric"] = ["AdvancedNormalizedCorrelation"]
DEFAULT_REGISTRATION_PARAMETERS_MAP["nl_anc"] = DEFAULT_REGISTRATION_PARAMETERS_MAP["nl"].copy()
DEFAULT_REGISTRATION_PARAMETERS_MAP["nl_anc"]["Metric"] = ["AdvancedNormalizedCorrelation"]

# do this here so we can exclude the test registrations
AVAILABLE_REGISTRATIONS = list(DEFAULT_REGISTRATION_PARAMETERS_MAP.keys())

# test
DEFAULT_REGISTRATION_PARAMETERS_MAP["rigid_test"] = DEFAULT_REGISTRATION_PARAMETERS_MAP["rigid"].copy()
DEFAULT_REGISTRATION_PARAMETERS_MAP["rigid_test"]["MaximumNumberOfIterations"] = ["10"]
DEFAULT_REGISTRATION_PARAMETERS_MAP["affine_test"] = DEFAULT_REGISTRATION_PARAMETERS_MAP["affine"].copy()
DEFAULT_REGISTRATION_PARAMETERS_MAP["affine_test"]["MaximumNumberOfIterations"] = ["10"]
DEFAULT_REGISTRATION_PARAMETERS_MAP["similarity_test"] = DEFAULT_REGISTRATION_PARAMETERS_MAP["similarity"].copy()
DEFAULT_REGISTRATION_PARAMETERS_MAP["similarity_test"]["MaximumNumberOfIterations"] = ["10"]
DEFAULT_REGISTRATION_PARAMETERS_MAP["nl_test"] = DEFAULT_REGISTRATION_PARAMETERS_MAP["nl"].copy()
DEFAULT_REGISTRATION_PARAMETERS_MAP["nl_test"]["MaximumNumberOfIterations"] = ["10"]
